@@ -12,7 +12,7 @@ use vars qw($conn);
 use DBI;
 use strict;
 
-our $VERSION = '1.1.1';
+my $VERSION = '1.1';
 
 # Inicia conexao
 sub new {
@@ -28,8 +28,6 @@ sub new {
 		bless {
 			conn => $conn,
 			type => $vars->{type},
-			error => undef,
-			pre => undef,
 		}, $self;
 	}
 
@@ -38,20 +36,20 @@ sub new {
 # Recupera dados do db
 sub return {
 	my ($self,$q,$t) = @_;
-	my (@array,@row,$row);
-
+	my (@array,@row,$row,$c);
+	
 	# Verifica formato de dados que deve retorna
 	$t = "scalar" if (!$t);
-
+	
 	# Prepara query
-	eval { $self->{pre} = $self->{conn}->prepare($q); };
+	eval { $c = $self->{conn}->prepare($q); };
 
 	# Verifica se conseguiu executar a query
-	eval { $self->{pre}->execute } or die DBI::errstr;
+	eval { $c->execute } or die DBI::errstr;
 	
 	# Retorna em formato array
 	if ($t eq "array") {
-		while (@row = $self->{pre}->fetchrow_array) {
+		while (@row = $c->fetchrow_array) {
 			push(@array,[ @row ]);
 		}
 	}
@@ -59,16 +57,16 @@ sub return {
 	# Retorna em formato hash
 	elsif ($t eq "scalar") {
 		eval { 
-			while ($row = $self->{pre}->fetchrow_hashref) {
+			while ($row = $c->fetchrow_hashref) {
 				push(@array,$row);
 			}
 		};
 	}
 
-	eval { $self->{pre}->finish };
+	eval { $c->finish };
 
 	# Apaga variaveis indesejadas
-	undef $q; undef $t;
+	undef $c; undef $q; undef $t;
 
 	# Retorna os resultados do select
 	return @array;
@@ -81,7 +79,7 @@ sub do {
 	$self->{conn}->do($q);
 	
 	if (DBI::errstr) {
-		$self->{error} = DBI::errstr;
+		die DBI::errstr;
 		return 0;
 	}
 	
@@ -112,13 +110,6 @@ sub disconnect {
 	$self = undef;
 }
 
-# Recupera numero de linhas
-sub rows {
-	my ($self) = @_;
-
-	return $self->{pre}->rows;
-}
-
 # Recupera ultima linha inserida
 sub insertid {
    my ($self) = @_;
@@ -127,12 +118,6 @@ sub insertid {
 	if ($self->{type} eq "mysql") { $self->{conn}->{mysql_insertid}; }
 }
 
-# retorn erro
-sub error {
-	my ($self) = @_;
-	return $self->{error};
-}
-
 1;
 
 =head1 NAME
